@@ -8,9 +8,11 @@ from pyinels.const import (
     ATTR_DOWN,
     ATTR_GROUP,
     ATTR_ID,
+    ATTR_UNKNOWN,
     ATTR_SHUTTER,
     ATTR_TEMP,
     ATTR_THERM,
+    ATTR_TITLE,
     ATTR_TYPE,
     ATTR_UP,
     DEVICE_TYPE_DICT,
@@ -190,8 +192,8 @@ class Api:
                 if item[start:end] == ":":
                     d_type = item[0:start]
 
-                    if d_type in "scenes":
-                        break
+                    # if d_type in "scenes":
+                    #     break
                 else:
                     json_dev = item.split('" ')
                     obj = {}
@@ -201,9 +203,13 @@ class Api:
                         frag = prop.split("=")
                         obj[frag[0]] = frag[1].replace("\"", " ").strip()
 
-                    obj[INELS_BUS_ATTR_DICT.get(ATTR_TYPE)] = DEVICE_TYPE_DICT.get(d_type)
+                    # obj[INELS_BUS_ATTR_DICT.get(ATTR_TYPE)] = DEVICE_TYPE_DICT.get(d_type)
 
-                    print(f"obj: {obj} , d_type: {d_type}")
+                    # print(f"obj: {obj} , d_type: {d_type}")
+
+                    obj[INELS_BUS_ATTR_DICT
+                        .get(ATTR_TYPE)] = DEVICE_TYPE_DICT.get(
+                            d_type, "unknown")
 
                     obj = self.__recognizeAndSetUniqueIdToDevice(obj)
 
@@ -236,6 +242,13 @@ class Api:
 
             return dev
 
+        def set_not_known_id_from_name(dev):
+            """Set the id to the not know device from name."""
+            name = dev[INELS_BUS_ATTR_DICT.get(ATTR_TITLE)].replace(" ", "_")
+            dev[INELS_BUS_ATTR_DICT.get(ATTR_ID)] = name
+
+            return dev
+
         # use a switch to create identifier inside of the raw data
         # from usefull attributes
 
@@ -246,7 +259,8 @@ class Api:
         if INELS_BUS_ATTR_DICT.get(ATTR_ID) not in raw_device:
             switcher = {
                 ATTR_SHUTTER: partial(set_shutter_id, raw_device),
-                ATTR_THERM: partial(set_therm_id, raw_device)
+                ATTR_THERM: partial(set_therm_id, raw_device),
+                ATTR_UNKNOWN: partial(set_not_known_id_from_name, raw_device)
             }
 
             # print("DOES THS GET HIT")
